pub struct WifiStaIfaceGetApfPacketFilterSupportResponse {
pub version: Option<i32>,
pub max_filter_length: Option<i32>,
/* private fields */
}Fields
version: Option<i32>max_filter_length: Option<i32>Trait Implementations
Sourceimpl Clone for WifiStaIfaceGetApfPacketFilterSupportResponse
impl Clone for WifiStaIfaceGetApfPacketFilterSupportResponse
Sourcefn clone(&self) -> WifiStaIfaceGetApfPacketFilterSupportResponse
fn clone(&self) -> WifiStaIfaceGetApfPacketFilterSupportResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<WifiStaIfaceGetApfPacketFilterSupportResponse, D> for WifiStaIfaceGetApfPacketFilterSupportResponse
impl<D: ResourceDialect> Decode<WifiStaIfaceGetApfPacketFilterSupportResponse, D> for WifiStaIfaceGetApfPacketFilterSupportResponse
Sourceimpl Default for WifiStaIfaceGetApfPacketFilterSupportResponse
impl Default for WifiStaIfaceGetApfPacketFilterSupportResponse
Sourcefn default() -> WifiStaIfaceGetApfPacketFilterSupportResponse
fn default() -> WifiStaIfaceGetApfPacketFilterSupportResponse
Returns the “default value” for a type. Read more
Sourceimpl<D: ResourceDialect> Encode<WifiStaIfaceGetApfPacketFilterSupportResponse, D> for &WifiStaIfaceGetApfPacketFilterSupportResponse
impl<D: ResourceDialect> Encode<WifiStaIfaceGetApfPacketFilterSupportResponse, D> for &WifiStaIfaceGetApfPacketFilterSupportResponse
Sourceimpl PartialEq for WifiStaIfaceGetApfPacketFilterSupportResponse
impl PartialEq for WifiStaIfaceGetApfPacketFilterSupportResponse
Sourcefn eq(&self, other: &WifiStaIfaceGetApfPacketFilterSupportResponse) -> bool
fn eq(&self, other: &WifiStaIfaceGetApfPacketFilterSupportResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TypeMarker for WifiStaIfaceGetApfPacketFilterSupportResponse
impl TypeMarker for WifiStaIfaceGetApfPacketFilterSupportResponse
Sourcetype Owned = WifiStaIfaceGetApfPacketFilterSupportResponse
type Owned = WifiStaIfaceGetApfPacketFilterSupportResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for WifiStaIfaceGetApfPacketFilterSupportResponse
impl ValueTypeMarker for WifiStaIfaceGetApfPacketFilterSupportResponse
Sourcetype Borrowed<'a> = &'a WifiStaIfaceGetApfPacketFilterSupportResponse
type Borrowed<'a> = &'a WifiStaIfaceGetApfPacketFilterSupportResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Persistable for WifiStaIfaceGetApfPacketFilterSupportResponse
impl StructuralPartialEq for WifiStaIfaceGetApfPacketFilterSupportResponse